@@ -1,25 +1,31 @@
 package Feersum::Connection::Handle;
+use warnings;
 use strict;
+use Carp qw/croak/;
 
 sub new {
-    Carp::croak "Cannot instantiate Feersum::Connection::Handles directly";
+    Carp::croak "Cannot instantiate Feersum::Connection::Handle directly";
 }
 
 package Feersum::Connection::Reader;
+use warnings;
 use strict;
 use base 'Feersum::Connection::Handle';
 
-sub write { Carp::croak "can't call write() on a read-only handle" }
+sub write { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call write() on a read-only handle" }
 
 package Feersum::Connection::Writer;
+use warnings;
 use strict;
 use base 'Feersum::Connection::Handle';
 
-sub read { Carp::croak "can't call read() on a write-only handle" }
-sub seek { Carp::croak "can't call seek() on a write-only handle" }
+sub read { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call read() on a write-only handle" }
+sub seek { ## no critic (BuiltinHomonyms)
+    Carp::croak "can't call seek() on a write-only handle" }
 
 package Feersum::Connection::Handle;
-
 1;
 __END__
 
@@ -48,6 +54,7 @@ For write handles:
 
     $w->write("scalar");
     $w->write(\"scalar ref");
+    $w->write_array(\@some_stuff);
     $w->poll_cb(sub {
         # use $_[0] instead of $w to avoid a closure
         $_[0]->write(\"some data");
@@ -101,7 +108,9 @@ Discards the remainder of the input buffer.
 
 =item C<< $r->poll_cb(sub { .... }) >>
 
-B<NOT YET SUPPORTED>.  PSGI only defined poll_cb for the Writer object.
+Register a callback to be called when more request body data is available.
+The callback receives the Reader object as its argument. Useful for streaming
+request body reads with Expect: 100-continue.
 
 =back
 
@@ -126,6 +135,12 @@ PSGI env hash (L<Twiggy> supports this too, for example).
 Works just like C<write("scalar")> above.  This extension is indicated by
 C<psgix.body.scalar_refs> in the PSGI env hash.
 
+=item C<< $w->write_array(\@array) >>
+
+Pass in an array-ref and it works much like the two C<write()> calls above,
+except it's way more efficient than calling C<write()> over and over.
+Undefined elements of the array are ignored.
+
 =item C<< $w->close() >>
 
 Close the HTTP response (which triggers the "T-E: chunked" terminating chunk
@@ -141,12 +156,35 @@ A reference to the writer is passed in as the first and only argument to the
 sub.  It's recommended that you use C<$_[0]> rather than closing-over on C<$w>
 to prevent a circular reference.
 
+=item C<< $w->sendfile($fh) >>
+
+Send file contents using zero-copy sendfile(2) system call. Linux only.
+The file handle should be a regular file opened for reading. The response
+should have a Content-Length header set to the file size. After calling
+sendfile(), call C<close()> on the writer.
+
+    my $w = $req->start_streaming(200, [
+        'Content-Type' => 'application/octet-stream',
+        'Content-Length' => -s $filename,
+    ]);
+    open my $fh, '<', $filename or die $!;
+    $w->sendfile($fh);
+    close $fh;
+
 =back
 
 =head2 Common methods.
 
 Methods in common to both types of handles.
 
+=begin comment
+
+=item C<< Feersum::Connection::Handle->new() >>
+
+Shouldn't be called directly; L<Feersum> will create these objects.
+
+=end comment
+
 =over 4
 
 =item C<< $h->response_guard($guard) >>
@@ -160,6 +198,10 @@ the response.
 
 C<psgix.output.guard> is the PSGI-env extension that indicates this method.
 
+=item C<< $h->fileno >>
+
+Returns the file descriptor number for this connection.
+
 =back
 
 =head1 AUTHOR
