@@ -79,7 +79,7 @@ sub _create_socket {
         umask($saved);  # Restore umask even if socket creation failed
         die $err if $err;
         croak "couldn't bind to socket: $!" unless $sock;
-        $sock->blocking(0) || croak "couldn't unblock socket: $!";
+        $sock->blocking(0) || do { close($sock); croak "couldn't unblock socket: $!"; };
     }
     else {
         require IO::Socket::INET;
@@ -364,7 +364,7 @@ sub _start_pre_fork {
 
     # pre_fork value already validated in _prepare()
 
-    POSIX::setsid() or carp "setsid() failed: $!";
+    POSIX::setsid() or croak "setsid() failed: $!";
 
     $self->{_kids} = [];
     $self->{_n_kids} = 0;
